﻿using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "Viewbox 엘리먼트 사용하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Stretch 라디오 버튼 체크시 처리하기 - stretchRadioButton_Checked(sender, e)

        /// <summary>
        /// Stretch 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void stretchRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            if(sender is RadioButton radioButton && this.viewbox != null)
            {
                string stretch = radioButton.Tag.ToString();

                switch(stretch)
                {
                    case "None"          : this.viewbox.Stretch = Stretch.None;          break;
                    case "Fill"          : this.viewbox.Stretch = Stretch.Fill;          break;
                    case "Uniform"       : this.viewbox.Stretch = Stretch.Uniform;       break;
                    case "UniformToFill" : this.viewbox.Stretch = Stretch.UniformToFill; break;
                }
            }
        }

        #endregion
        #region StretchDirection 라디오 버튼 체크시 처리하기 - stretchDirectionRadiobButton_Checked(sender, e)

        /// <summary>
        /// StretchDirection 라디오 버튼 체크시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void stretchDirectionRadiobButton_Checked(object sender, RoutedEventArgs e)
        {
            if(sender is RadioButton radioButton && this.viewbox != null)
            {
                string stretchDirection = radioButton.Tag.ToString();

                switch(stretchDirection)
                {
                    case "UpOnly"   : this.viewbox.StretchDirection = StretchDirection.UpOnly;   break;
                    case "DownOnly" : this.viewbox.StretchDirection = StretchDirection.DownOnly; break;
                    case "Both"     : this.viewbox.StretchDirection = StretchDirection.Both;     break;
                }
            }
        }

        #endregion
    }
}